# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class AcceleratorConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'acc_class': 'str',
        'quantity': 'int',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'acc_class': 'acc_class',
        'quantity': 'quantity',
        'description': 'description'
    }

    def __init__(self, name=None, acc_class=None, quantity=None, description=None, local_vars_configuration=None):  # noqa: E501
        """AcceleratorConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._acc_class = None
        self._quantity = None
        self._description = None
        self.discriminator = None

        self.name = name
        self.acc_class = acc_class
        if quantity is not None:
            self.quantity = quantity
        self.description = description

    @property
    def name(self):
        """Gets the name of this AcceleratorConfig.  # noqa: E501


        :return: The name of this AcceleratorConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AcceleratorConfig.


        :param name: The name of this AcceleratorConfig.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def acc_class(self):
        """Gets the acc_class of this AcceleratorConfig.  # noqa: E501


        :return: The acc_class of this AcceleratorConfig.  # noqa: E501
        :rtype: str
        """
        return self._acc_class

    @acc_class.setter
    def acc_class(self, acc_class):
        """Sets the acc_class of this AcceleratorConfig.


        :param acc_class: The acc_class of this AcceleratorConfig.  # noqa: E501
        :type acc_class: str
        """
        if self.local_vars_configuration.client_side_validation and acc_class is None:  # noqa: E501
            raise ValueError("Invalid value for `acc_class`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                acc_class is not None and len(acc_class) > 100):
            raise ValueError("Invalid value for `acc_class`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                acc_class is not None and len(acc_class) < 1):
            raise ValueError("Invalid value for `acc_class`, length must be greater than or equal to `1`")  # noqa: E501

        self._acc_class = acc_class

    @property
    def quantity(self):
        """Gets the quantity of this AcceleratorConfig.  # noqa: E501


        :return: The quantity of this AcceleratorConfig.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this AcceleratorConfig.


        :param quantity: The quantity of this AcceleratorConfig.  # noqa: E501
        :type quantity: int
        """
        if (self.local_vars_configuration.client_side_validation and
                quantity is not None and quantity > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                quantity is not None and quantity < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._quantity = quantity

    @property
    def description(self):
        """Gets the description of this AcceleratorConfig.  # noqa: E501


        :return: The description of this AcceleratorConfig.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AcceleratorConfig.


        :param description: The description of this AcceleratorConfig.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AcceleratorConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AcceleratorConfig):
            return True

        return self.to_dict() != other.to_dict()
