# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class TeamDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'number_of_members': 'int',
        'user_role': 'str',
        'members': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'number_of_members': 'number_of_members',
        'user_role': 'user_role',
        'members': 'members'
    }

    def __init__(self, id=None, name=None, number_of_members=None, user_role=None, members=None, local_vars_configuration=None):  # noqa: E501
        """TeamDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._number_of_members = None
        self._user_role = None
        self._members = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if number_of_members is not None:
            self.number_of_members = number_of_members
        if user_role is not None:
            self.user_role = user_role
        if members is not None:
            self.members = members

    @property
    def id(self):
        """Gets the id of this TeamDetails.  # noqa: E501

        ID for this team  # noqa: E501

        :return: The id of this TeamDetails.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TeamDetails.

        ID for this team  # noqa: E501

        :param id: The id of this TeamDetails.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this TeamDetails.  # noqa: E501

        Name of this team  # noqa: E501

        :return: The name of this TeamDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TeamDetails.

        Name of this team  # noqa: E501

        :param name: The name of this TeamDetails.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def number_of_members(self):
        """Gets the number_of_members of this TeamDetails.  # noqa: E501

        Number of members in this team  # noqa: E501

        :return: The number_of_members of this TeamDetails.  # noqa: E501
        :rtype: int
        """
        return self._number_of_members

    @number_of_members.setter
    def number_of_members(self, number_of_members):
        """Sets the number_of_members of this TeamDetails.

        Number of members in this team  # noqa: E501

        :param number_of_members: The number_of_members of this TeamDetails.  # noqa: E501
        :type number_of_members: int
        """

        self._number_of_members = number_of_members

    @property
    def user_role(self):
        """Gets the user_role of this TeamDetails.  # noqa: E501

        Your role in this team  # noqa: E501

        :return: The user_role of this TeamDetails.  # noqa: E501
        :rtype: str
        """
        return self._user_role

    @user_role.setter
    def user_role(self, user_role):
        """Sets the user_role of this TeamDetails.

        Your role in this team  # noqa: E501

        :param user_role: The user_role of this TeamDetails.  # noqa: E501
        :type user_role: str
        """

        self._user_role = user_role

    @property
    def members(self):
        """Gets the members of this TeamDetails.  # noqa: E501

        List of user ids and roles for members of this team  # noqa: E501

        :return: The members of this TeamDetails.  # noqa: E501
        :rtype: str
        """
        return self._members

    @members.setter
    def members(self, members):
        """Sets the members of this TeamDetails.

        List of user ids and roles for members of this team  # noqa: E501

        :param members: The members of this TeamDetails.  # noqa: E501
        :type members: str
        """

        self._members = members

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TeamDetails):
            return True

        return self.to_dict() != other.to_dict()
